<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AppChooserDialog</name>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="14"/>
        <source>Choose an Application</source>
        <translation>Escolha uma aplicação</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="36"/>
        <source>Installed Applications</source>
        <translation>Aplicações instaladas</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="46"/>
        <source>Custom Command</source>
        <translation>Comando personalizado</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="52"/>
        <source>Command line to execute:</source>
        <translation>Linha de comandos a executar:</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="62"/>
        <source>Application name:</source>
        <translation>Nome da aplicação:</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="72"/>
        <source>&lt;b&gt;These special codes can be used in the command line:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: Represents a single file name&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: Represents multiple file names&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: Represents a single URI of the file&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: Represents multiple URIs&lt;/li&gt;
&lt;/ul&gt;</source>
        <translation>&lt;b&gt;Pode utilizar os seguintes códigos na linha de comandos:&lt;/b&gt;
&lt;ul&gt;
&lt;li&gt;&lt;b&gt;%f&lt;/b&gt;: é o nome de um ficheiro&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%F&lt;/b&gt;: é o nome de vários ficheiros&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%u&lt;/b&gt;: é o URI do ficheiro&lt;/li&gt;
&lt;li&gt;&lt;b&gt;%U&lt;/b&gt;: é o URI de vários ficheiros&lt;/li&gt;
&lt;/ul&gt;</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="91"/>
        <source>Keep terminal window open after command execution</source>
        <translation>Manter janela de terminal aberta depois de executar o comando</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="98"/>
        <source>Execute in terminal emulator</source>
        <translation>Executar no emulador de terminal</translation>
    </message>
    <message>
        <location filename="../../app-chooser-dialog.ui" line="109"/>
        <source>Set selected application as default action of this file type</source>
        <translation>Utilizar a aplicação selecionada como padrão para este tipo de ficheiro</translation>
    </message>
</context>
<context>
    <name>EditBookmarksDialog</name>
    <message>
        <location filename="../../edit-bookmarks.ui" line="14"/>
        <source>Edit Bookmarks</source>
        <translation>Editar marcadores</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="42"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="47"/>
        <source>Location</source>
        <translation>Localização</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="67"/>
        <source>&amp;Add Item</source>
        <translation>&amp;Adicionar item</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="77"/>
        <source>&amp;Remove Item</source>
        <translation>&amp;Remover item</translation>
    </message>
    <message>
        <location filename="../../edit-bookmarks.ui" line="102"/>
        <source>Use drag and drop to reorder the items</source>
        <translation>Arraste e largue para organizar itens</translation>
    </message>
</context>
<context>
    <name>ExecFileDialog</name>
    <message>
        <location filename="../../exec-file.ui" line="14"/>
        <source>Execute file</source>
        <translation>Executar ficheiro</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="39"/>
        <source>&amp;Open</source>
        <translation>&amp;Abrir</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="52"/>
        <source>E&amp;xecute</source>
        <translation>E&amp;xecutar</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="62"/>
        <source>Execute in &amp;Terminal</source>
        <translation>Executar no &amp;terminal</translation>
    </message>
    <message>
        <location filename="../../exec-file.ui" line="85"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>FileOperationDialog</name>
    <message>
        <location filename="../../file-operation-dialog.ui" line="32"/>
        <source>Destination:</source>
        <translation>Destino:</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="55"/>
        <source>Processing:</source>
        <translation>Processamento:</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="68"/>
        <source>Preparing...</source>
        <translation>Preparação...</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="75"/>
        <source>Progress</source>
        <translation>Evolução</translation>
    </message>
    <message>
        <location filename="../../file-operation-dialog.ui" line="95"/>
        <source>Time remaining:</source>
        <translation>Tempo restante:</translation>
    </message>
</context>
<context>
    <name>FilePropsDialog</name>
    <message>
        <location filename="../../file-props.ui" line="14"/>
        <source>File Properties</source>
        <translation>Propriedades do ficheiro</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="41"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="80"/>
        <source>Location:</source>
        <translation>Localização:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="106"/>
        <source>File type:</source>
        <translation>Tipo de ficheiro:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="129"/>
        <source>MIME type:</source>
        <translation>Tipo MIME:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="152"/>
        <source>File size:</source>
        <translation>Tamanho do ficheiro:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="175"/>
        <source>On-disk size:</source>
        <translation>Tamanho no disco:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="198"/>
        <source>Last modified:</source>
        <translation>Última modificação:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="221"/>
        <source>Link target:</source>
        <translation>Destino da ligação:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="247"/>
        <source>Open With:</source>
        <translation>Abrir com:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="267"/>
        <source>Last accessed:</source>
        <translation>Último acesso:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="285"/>
        <source>Permissions</source>
        <translation>Permissões</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="300"/>
        <source>Ownership</source>
        <translation>Titulariedade</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="324"/>
        <location filename="../../file-props.ui" line="389"/>
        <location filename="../../file-props.ui" line="503"/>
        <source>Group:</source>
        <translation>Grupo:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="337"/>
        <location filename="../../file-props.ui" line="372"/>
        <location filename="../../file-props.ui" line="451"/>
        <source>Owner:</source>
        <translation>Dono:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="353"/>
        <source>Access Control</source>
        <translation>Controlo de acesso</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="406"/>
        <location filename="../../file-props.ui" line="555"/>
        <source>Other:</source>
        <translation>Outro:</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="423"/>
        <source>Make the file executable</source>
        <translation>Marcar como executável</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="464"/>
        <location filename="../../file-props.ui" line="516"/>
        <location filename="../../file-props.ui" line="568"/>
        <source>Read</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="477"/>
        <location filename="../../file-props.ui" line="529"/>
        <location filename="../../file-props.ui" line="581"/>
        <source>Write</source>
        <translation>Escrita</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="490"/>
        <location filename="../../file-props.ui" line="542"/>
        <location filename="../../file-props.ui" line="594"/>
        <source>Execute</source>
        <translation>Execução</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="603"/>
        <source>Sticky</source>
        <translation>Fixo</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="610"/>
        <source>SetUID</source>
        <translation>Definir UID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="617"/>
        <source>SetGID</source>
        <translation>Definir GID</translation>
    </message>
    <message>
        <location filename="../../file-props.ui" line="653"/>
        <source>Advanced Mode</source>
        <translation>Modo avançado</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserComboBox</name>
    <message>
        <location filename="../../appchoosercombobox.cpp" line="67"/>
        <source>Customize</source>
        <translation>Personalizar</translation>
    </message>
</context>
<context>
    <name>Fm::AppChooserDialog</name>
    <message>
        <location filename="../../appchooserdialog.cpp" line="262"/>
        <source>Select an application to open &quot;%1&quot; files</source>
        <translation>Selecione a aplicação para abrir os ficheiros %1</translation>
    </message>
</context>
<context>
    <name>Fm::CreateNewMenu</name>
    <message>
        <location filename="../../createnewmenu.cpp" line="30"/>
        <source>Folder</source>
        <translation>Pasta</translation>
    </message>
    <message>
        <location filename="../../createnewmenu.cpp" line="34"/>
        <source>Blank File</source>
        <translation>Ficheiro vazio</translation>
    </message>
</context>
<context>
    <name>Fm::DirListJob</name>
    <message>
        <location filename="../../core/dirlistjob.cpp" line="45"/>
        <source>The specified directory &apos;%1&apos; is not valid</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeModel</name>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="85"/>
        <source>Loading...</source>
        <translation>A carregar...</translation>
    </message>
    <message>
        <location filename="../../dirtreemodelitem.cpp" line="268"/>
        <location filename="../../dirtreemodelitem.cpp" line="312"/>
        <location filename="../../dirtreemodelitem.cpp" line="410"/>
        <source>&lt;No sub folders&gt;</source>
        <translation>&lt;Não existem subpastas&gt;</translation>
    </message>
</context>
<context>
    <name>Fm::DirTreeView</name>
    <message>
        <location filename="../../dirtreeview.cpp" line="211"/>
        <source>Open in New T&amp;ab</source>
        <translation>Abrir em novo sep&amp;arador</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="215"/>
        <source>Open in New Win&amp;dow</source>
        <translation>Abrir em nova ja&amp;nela</translation>
    </message>
    <message>
        <location filename="../../dirtreeview.cpp" line="220"/>
        <source>Open in Termina&amp;l</source>
        <translation>Abrir no termina&amp;l</translation>
    </message>
</context>
<context>
    <name>Fm::DndActionMenu</name>
    <message>
        <location filename="../../dndactionmenu.cpp" line="32"/>
        <source>Copy here</source>
        <translation>Copiar aqui</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="35"/>
        <source>Move here</source>
        <translation>Mover aqui</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="38"/>
        <source>Create symlink here</source>
        <translation>Criar ligação simbólica aqui</translation>
    </message>
    <message>
        <location filename="../../dndactionmenu.cpp" line="41"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>Fm::EditBookmarksDialog</name>
    <message>
        <location filename="../../editbookmarksdialog.cpp" line="98"/>
        <source>New bookmark</source>
        <translation>Novo marcador</translation>
    </message>
</context>
<context>
    <name>Fm::ExecFileDialog</name>
    <message>
        <location filename="../../execfiledialog.cpp" line="40"/>
        <source>This text file &apos;%1&apos; seems to be an executable script.
What do you want to do with it?</source>
        <translation>Parece que o ficheiro de texto %1 é um script executável.
O que pretende fazer com o ficheiro?</translation>
    </message>
    <message>
        <location filename="../../execfiledialog.cpp" line="45"/>
        <source>This file &apos;%1&apos; is executable. Do you want to execute it?</source>
        <translation>O ficheiro %1 é um executável. Pretende executar o ficheiro?</translation>
    </message>
</context>
<context>
    <name>Fm::FileMenu</name>
    <message>
        <location filename="../../filemenu.cpp" line="82"/>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>OpenWith</source>
        <translation type="obsolete">Abrir com</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="145"/>
        <source>Cut</source>
        <translation>Cortar</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="149"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="153"/>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="157"/>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Move to Trash</source>
        <translation>&amp;Mover para o lixo</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="297"/>
        <source>Output</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="348"/>
        <source>&amp;Delete</source>
        <translation>&amp;Apagar</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="161"/>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="86"/>
        <source>Open With...</source>
        <translation>Abrir com...</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="114"/>
        <source>Other Applications</source>
        <translation>Outras aplicações</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="120"/>
        <source>Create &amp;New</source>
        <translation>Criar &amp;novo(a)</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="139"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurar</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="188"/>
        <source>Extract to...</source>
        <translation>Extrair para...</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="193"/>
        <source>Extract Here</source>
        <translation>Extrair aqui</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="199"/>
        <source>Compress</source>
        <translation>Comprimir</translation>
    </message>
    <message>
        <location filename="../../filemenu.cpp" line="209"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperation</name>
    <message>
        <location filename="../../fileoperation.cpp" line="227"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="228"/>
        <source>Some files cannot be moved to trash can because the underlying file systems don&apos;t support this operation.
Do you want to delete them instead?</source>
        <translation>Alguns ficheiros não podem ser movidos para o lixo porque o sistema de ficheiros não suporta esta operação.
Deseja apagar permanentemente estes ficheiros?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="270"/>
        <location filename="../../fileoperation.cpp" line="287"/>
        <source>Confirm</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="271"/>
        <source>Do you want to delete the selected files?</source>
        <translation>Quer mesmo apagar o(s) ficheiro(s) selecionado(s)?</translation>
    </message>
    <message>
        <location filename="../../fileoperation.cpp" line="288"/>
        <source>Do you want to move the selected files to trash can?</source>
        <translation>Quer mesmo mover o(s) ficheiro(s) selecionado(s) para o lixo?</translation>
    </message>
</context>
<context>
    <name>Fm::FileOperationDialog</name>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="41"/>
        <source>Move files</source>
        <translation>Mover ficheiros</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="42"/>
        <source>Moving the following files to destination folder:</source>
        <translation>A mover os ficheiros para a pasta de destino:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="45"/>
        <source>Copy Files</source>
        <translation>Copiar ficheiros</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="46"/>
        <source>Copying the following files to destination folder:</source>
        <translation>A copiar os ficheiros para a pasta de destino:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="49"/>
        <source>Trash Files</source>
        <translation>Destruir ficheiros</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="50"/>
        <source>Moving the following files to trash can:</source>
        <translation>A mover os ficheiros para o lixo:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="53"/>
        <source>Delete Files</source>
        <translation>Apagar ficheiros</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="54"/>
        <source>Deleting the following files:</source>
        <translation>A apagar estes ficheiros:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="59"/>
        <source>Create Symlinks</source>
        <translation>Criar ligações simbólicas</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="60"/>
        <source>Creating symlinks for the following files:</source>
        <translation>A criar ligações simbólicas a estes ficheiros:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="63"/>
        <source>Change Attributes</source>
        <translation>Alterar atributos</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="64"/>
        <source>Changing attributes of the following files:</source>
        <translation>A alterar os atributos destes ficheiros:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="69"/>
        <source>Restore Trashed Files</source>
        <translation>Restaurar ficheiros apagados</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="70"/>
        <source>Restoring the following files from trash can:</source>
        <translation>Restaurar estes ficheiros do lixo:</translation>
    </message>
    <message>
        <location filename="../../fileoperationdialog.cpp" line="134"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>Fm::FilePropsDialog</name>
    <message>
        <location filename="../../filepropsdialog.cpp" line="156"/>
        <source>View folder content</source>
        <translation>Ver conteúdo da pasta</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="157"/>
        <source>View and modify folder content</source>
        <translation>Ver e modificar conteúdo da pasta</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="161"/>
        <source>Read</source>
        <translation>Leitura</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="162"/>
        <source>Read and write</source>
        <translation>Leitura e escrita</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="164"/>
        <source>Forbidden</source>
        <translation>Proibido</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="281"/>
        <source>Files of different types</source>
        <translation>Ficheiros de outro tipo</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="304"/>
        <source>Multiple Files</source>
        <translation>Vários ficheiros</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="380"/>
        <source>Select an icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="382"/>
        <source>Images (*.png *.xpm *.svg *.svgz )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="478"/>
        <source>Apply changes</source>
        <translation>Aplicar alterações</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="479"/>
        <source>Do you want to recursively apply these changes to all files and sub-folders?</source>
        <translation>Pretende aplicar as alterações a todos os ficheiros e subpastas?</translation>
    </message>
</context>
<context>
    <name>Fm::FileSearchDialog</name>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="128"/>
        <source>You should add at least one directory to search.</source>
        <translation>Deve adicionar, pelo menos, um diretório para pesquisar.</translation>
    </message>
    <message>
        <location filename="../../filesearchdialog.cpp" line="135"/>
        <source>Select a folder</source>
        <translation>Selecionar uma pasta</translation>
    </message>
</context>
<context>
    <name>Fm::FolderMenu</name>
    <message>
        <location filename="../../foldermenu.cpp" line="41"/>
        <source>Create &amp;New</source>
        <translation>Criar &amp;novo(a)</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="48"/>
        <source>&amp;Paste</source>
        <translation>Co&amp;lar</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="54"/>
        <source>Select &amp;All</source>
        <translation>Selecion&amp;ar tudo</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="58"/>
        <source>Invert Selection</source>
        <translation>Inverter seleção</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="64"/>
        <source>Sorting</source>
        <translation>Ordenação</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="69"/>
        <source>Show Hidden</source>
        <translation>Mostrar ocultos</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="94"/>
        <source>Folder Pr&amp;operties</source>
        <translation>Pr&amp;opriedades da pasta</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation type="vanished">Pasta</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="obsolete">Ficheiro</translation>
    </message>
    <message>
        <source>Blank File</source>
        <translation type="vanished">Ficheiro vazio</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="137"/>
        <source>Output</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="160"/>
        <source>By File Name</source>
        <translation>Por nome de ficheiro</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="161"/>
        <source>By Modification Time</source>
        <translation>Por data de modificação</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="162"/>
        <source>By File Size</source>
        <translation>Por tamanho de ficheiro</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="163"/>
        <source>By File Type</source>
        <translation>Por tipo de ficheiro</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="164"/>
        <source>By File Owner</source>
        <translation>Por dono de ficheiro</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="176"/>
        <source>Ascending</source>
        <translation>Ascendente</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="181"/>
        <source>Descending</source>
        <translation>Descendente</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="198"/>
        <source>Folder First</source>
        <translation>Pastas no início</translation>
    </message>
    <message>
        <location filename="../../foldermenu.cpp" line="208"/>
        <source>Case Sensitive</source>
        <translation>Diferenciar maiúsculas/minúsculas</translation>
    </message>
</context>
<context>
    <name>Fm::FolderModel</name>
    <message>
        <location filename="../../foldermodel.cpp" line="242"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="245"/>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="248"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="251"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../foldermodel.cpp" line="254"/>
        <source>Owner</source>
        <translation>Dono</translation>
    </message>
</context>
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Negrito</translation>
    </message>
    <message>
        <location filename="../../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Itálico</translation>
    </message>
</context>
<context>
    <name>Fm::MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mountoperationpassworddialog.cpp" line="40"/>
        <source>&amp;Connect</source>
        <translation>&amp;Ligar</translation>
    </message>
</context>
<context>
    <name>Fm::PathBar</name>
    <message>
        <location filename="../../pathbar.cpp" line="126"/>
        <source>&amp;Edit Path</source>
        <translation>&amp;Editar caminho</translation>
    </message>
    <message>
        <location filename="../../pathbar.cpp" line="129"/>
        <source>&amp;Copy Path</source>
        <translation>&amp;Copiar caminho</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesModel</name>
    <message>
        <location filename="../../placesmodel.cpp" line="44"/>
        <source>Places</source>
        <translation>Locais</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="52"/>
        <source>Desktop</source>
        <translation>Área de trabalho</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="231"/>
        <source>Trash</source>
        <translation>Lixo</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="60"/>
        <source>Computer</source>
        <translation>Computador</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="72"/>
        <source>Applications</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="81"/>
        <source>Network</source>
        <translation>Rede</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="88"/>
        <source>Devices</source>
        <translation>Dispositivos</translation>
    </message>
    <message>
        <location filename="../../placesmodel.cpp" line="142"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
</context>
<context>
    <name>Fm::PlacesView</name>
    <message>
        <location filename="../../placesview.cpp" line="370"/>
        <source>Empty Trash</source>
        <translation>Esvaziar lixo</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="vanished">Renomear</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="vanished">Apagar</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="356"/>
        <source>Open in New Tab</source>
        <translation>Abrir em novo separador</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="359"/>
        <source>Open in New Window</source>
        <translation>Abrir em nova janela</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="379"/>
        <source>Move Bookmark Up</source>
        <translation>Mover marcador para cima</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="384"/>
        <source>Move Bookmark Down</source>
        <translation>Mover marcador para baixo</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="388"/>
        <source>Rename Bookmark</source>
        <translation>Renomear marcador</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="391"/>
        <source>Remove Bookmark</source>
        <translation>Remover marcador</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="400"/>
        <location filename="../../placesview.cpp" line="417"/>
        <source>Unmount</source>
        <translation>Desmontar</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="404"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../../placesview.cpp" line="410"/>
        <source>Eject</source>
        <translation>Ejetar</translation>
    </message>
</context>
<context>
    <name>Fm::RenameDialog</name>
    <message>
        <location filename="../../renamedialog.cpp" line="50"/>
        <location filename="../../renamedialog.cpp" line="69"/>
        <source>Type: %1
Size: %2
Modified: %3</source>
        <translation>Tipo: %1
Tamanho: %2
Modificado: %3</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="56"/>
        <location filename="../../renamedialog.cpp" line="75"/>
        <source>Type: %1
Modified: %2</source>
        <translation>Tipo: %1
Modificado: %2</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="89"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Substituir</translation>
    </message>
    <message>
        <location filename="../../renamedialog.cpp" line="91"/>
        <source>&amp;Rename</source>
        <translation>&amp;Renomear</translation>
    </message>
</context>
<context>
    <name>Fm::SidePane</name>
    <message>
        <location filename="../../sidepane.cpp" line="46"/>
        <source>Places</source>
        <translation>Locais</translation>
    </message>
    <message>
        <location filename="../../sidepane.cpp" line="47"/>
        <source>Directory Tree</source>
        <translation>Árvore de diretórios</translation>
    </message>
    <message>
        <source>Shows list of common places, devices, and bookmarks in sidebar</source>
        <translation type="vanished">Mostra a lista de locais, dispositivos e marcadores na barra lateral</translation>
    </message>
    <message>
        <source>Shows tree of directories in sidebar</source>
        <translation type="vanished">Mostra a árvore de diretórios na barra lateral</translation>
    </message>
</context>
<context>
    <name>MountOperationPasswordDialog</name>
    <message>
        <location filename="../../mount-operation-password.ui" line="20"/>
        <source>Mount</source>
        <translation>Montar</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="48"/>
        <source>Connect &amp;anonymously</source>
        <translation>Ligar &amp;anonimamente</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="58"/>
        <source>Connect as u&amp;ser:</source>
        <translation>Ligar com utili&amp;zador:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="79"/>
        <source>&amp;Username:</source>
        <translation>Nome de &amp;utilizador:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="102"/>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="112"/>
        <source>&amp;Domain:</source>
        <translation>&amp;Domínio:</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="127"/>
        <source>Forget password &amp;immediately</source>
        <translation>Esquecer senha &amp;imediatamente</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="137"/>
        <source>Remember password until you &amp;logout</source>
        <translation>Memorizar sen&amp;ha até fechar a sessão</translation>
    </message>
    <message>
        <location filename="../../mount-operation-password.ui" line="147"/>
        <source>Remember &amp;forever</source>
        <translation>Memorizar &amp;eternamente</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../utilities.cpp" line="143"/>
        <location filename="../../utilities.cpp" line="232"/>
        <location filename="../../mountoperation.cpp" line="186"/>
        <location filename="../../filepropsdialog.cpp" line="503"/>
        <location filename="../../filelauncher.cpp" line="139"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="149"/>
        <source>Rename File</source>
        <translation>Renomear ficheiro</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="150"/>
        <source>Please enter a new name:</source>
        <translation>Introduza o novo nome:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="174"/>
        <source>Create Folder</source>
        <translation>Criar pasta</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="179"/>
        <source>Please enter a new file name:</source>
        <translation>Introduza o nome do ficheiro:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="180"/>
        <source>New text file</source>
        <translation>Novo ficheiro de texto</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="184"/>
        <source>Please enter a new folder name:</source>
        <translation>Introduza o nome da pasta:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="185"/>
        <source>New folder</source>
        <translation>Nova pasta</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="190"/>
        <source>Enter a name for the new %1:</source>
        <translation>Introduza o nome para %1:</translation>
    </message>
    <message>
        <location filename="../../utilities.cpp" line="175"/>
        <source>Create File</source>
        <translation>Criar ficheiro</translation>
    </message>
    <message>
        <location filename="../../filepropsdialog.cpp" line="520"/>
        <source>Custom Icon Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <location filename="../../rename-dialog.ui" line="14"/>
        <source>Confirm to replace files</source>
        <translation>Confirmação de substituição</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="35"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;There is already a file with the same name in this location.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Do you want to replace the existing file?&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Já existe um ficheiro com o mesmo nome nesta localização.&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Pretende substituir o ficheiro existente&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="56"/>
        <source>dest</source>
        <translation>destino</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="63"/>
        <source>with the following file?</source>
        <translation>por este?</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="76"/>
        <source>src file info</source>
        <translation>informações do ficheiro de origem</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="89"/>
        <source>dest file info</source>
        <translation>informações do ficheiro de destino</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="102"/>
        <source>src</source>
        <translation>origem</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="122"/>
        <source>&amp;File name:</source>
        <translation>Nome do &amp;ficheiro:</translation>
    </message>
    <message>
        <location filename="../../rename-dialog.ui" line="137"/>
        <source>Apply this option to all existing files</source>
        <translation>Aplicar opção a todos os ficheiros existentes</translation>
    </message>
</context>
<context>
    <name>SearchDialog</name>
    <message>
        <location filename="../../filesearch.ui" line="14"/>
        <source>Search Files</source>
        <translation>Pesquisar ficheiros</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="29"/>
        <source>Name/Location</source>
        <translation>Nome/localização</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="35"/>
        <source>File Name Patterns:</source>
        <translation>Padrão para nome de ficheiros:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="41"/>
        <source>*</source>
        <translation>*</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="48"/>
        <source>Case insensitive</source>
        <translation>Não diferenciar maiúsculas/minúsculas</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="55"/>
        <source>Use regular expression</source>
        <translation>Utilizar expressão regular</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="65"/>
        <source>Places to Search:</source>
        <translation>Locais a pesquisar:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="78"/>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="90"/>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="119"/>
        <source>Search in sub directories</source>
        <translation>Pesquisar nos subdiretórios</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="126"/>
        <source>Search for hidden files</source>
        <translation>Pesquisar por ficheiros ocultos</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="137"/>
        <source>File Type</source>
        <translation>Tipo de ficheiro</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="143"/>
        <source>Only search for files of following types:</source>
        <translation>Apenas pesquisar ficheiros destes tipos:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="149"/>
        <source>Text files</source>
        <translation>Ficheiros de texto</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="156"/>
        <source>Image files</source>
        <translation>Ficheiros de imagem</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="163"/>
        <source>Audio files</source>
        <translation>Ficheiros de áudio</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="170"/>
        <source>Video files</source>
        <translation>Ficheiros de vídeo</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="177"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="184"/>
        <source>Folders</source>
        <translation>Pastas</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="208"/>
        <source>Content</source>
        <translation>Conteúdo</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="214"/>
        <source>File contains:</source>
        <translation>Ficheiro contém:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="223"/>
        <source>Case insensiti&amp;ve</source>
        <translation>Não diferenciar maiúsculas/minúsc&amp;ulas</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="230"/>
        <source>&amp;Use regular expression</source>
        <translation>&amp;Utilizar expressão regular</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="254"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="260"/>
        <source>File Size:</source>
        <translation>Tamanho do ficheiro:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="289"/>
        <source>Larger than:</source>
        <translation>Maior que:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="303"/>
        <location filename="../../filesearch.ui" line="333"/>
        <source>Bytes</source>
        <translation>Bytes</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="308"/>
        <location filename="../../filesearch.ui" line="338"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="313"/>
        <location filename="../../filesearch.ui" line="343"/>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="318"/>
        <location filename="../../filesearch.ui" line="348"/>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="268"/>
        <source>Smaller than:</source>
        <translation>Menor que:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="364"/>
        <source>Last Modified Time:</source>
        <translation>Data da última modificação:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="372"/>
        <source>Earlier than:</source>
        <translation>Anterior a:</translation>
    </message>
    <message>
        <location filename="../../filesearch.ui" line="379"/>
        <source>Later than:</source>
        <translation>Posterior a:</translation>
    </message>
</context>
</TS>
